##  Selecting an SAP LeanIX Relation
First, select the relation that is to be used on the SAP LeanIX side. Depending on the Source you selected in the previous step, this is either the relation in SAP LeanIX that is read from or the relation that is created based on a relation within ServiceNow.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745f2a27a4410149c6e8650a31c924d_LowRes.png)
